@@ -1,8 +1,9 @@
 from reals._real import Real
 from reals._constants import e, phi, pi
 from reals._exponential import exp
+from reals._logarithm import log
 from reals._sqrt import sqrt
 from reals._trigonometric import sin, sinh, csc, csch, cos, cosh, sec, sech, tan, tanh, cot, coth
 
-__all__ = ['Real', 'e', 'phi', 'pi', 'exp', 'sqrt', 'sin', 'sinh', 'csc', 'csch', 'cos', 'cosh', 'sec', 'sech', 'tan',
-           'tanh', 'cot', 'coth']
+__all__ = ['Real', 'e', 'phi', 'pi', 'exp', 'log', 'sqrt', 'sin', 'sinh', 'csc', 'csch', 'cos', 'cosh', 'sec', 'sech',
+           'tan', 'tanh', 'cot', 'coth']
